@@ -21,7 +21,6 @@
 #ifndef XDG_DESKTOP_PORTAL_KDE_SCREENCHOOSER_DIALOG_H
 #define XDG_DESKTOP_PORTAL_KDE_SCREENCHOOSER_DIALOG_H
 
-#include <QAbstractListModel>
 #include <QDialog>
 
 namespace Ui
@@ -29,19 +28,17 @@ namespace Ui
 class ScreenChooserDialog;
 }
 
-class ScreenCastPortalOutput;
-
 class ScreenChooserDialog : public QDialog
 {
     Q_OBJECT
 public:
-    ScreenChooserDialog(const QMap<quint32, ScreenCastPortalOutput> &screens, bool multiple = false, QDialog *parent = nullptr, Qt::WindowFlags flags = {});
+    ScreenChooserDialog(const QString &appName, bool multiple, QDialog *parent = nullptr, Qt::WindowFlags flags = {});
     ~ScreenChooserDialog();
 
     QList<quint32> selectedScreens() const;
 
 private:
-    Ui::ScreenChooserDialog * m_dialog;
+    Ui::ScreenChooserDialog *m_dialog;
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_SCREENCHOOSER_DIALOG_H
